//=================================================================================================
/*!
//  \file blaze/math/Constants.h
//  \brief Header file for mathematical constants
//
//  Copyright (C) 2011 Klaus Iglberger - All Rights Reserved
//
//  This file is part of the Blaze library. This library is free software; you can redistribute
//  it and/or modify it under the terms of the GNU General Public License as published by the
//  Free Software Foundation; either version 3, or (at your option) any later version.
//
//  This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
//  without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//  See the GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License along with a special
//  exception for linking and compiling against the Blaze library, the so-called "runtime
//  exception"; see the file COPYING. If not, see http://www.gnu.org/licenses/.
*/
//=================================================================================================

#ifndef _BLAZE_MATH_CONSTANTS_H_
#define _BLAZE_MATH_CONSTANTS_H_


//*************************************************************************************************
// Includes
//*************************************************************************************************

#include <cmath>
#include <blaze/system/Precision.h>


namespace blaze {

//=================================================================================================
//
//  MATHEMATICAL CONSTANT E
//
//=================================================================================================

#ifdef M_E
#  undef M_E
#endif

//*************************************************************************************************
/*!\brief Definition of the mathematical constant \f$ e \f$.
// \ingroup math
*/
const real M_E = 2.7182818284590452353602874713526625;
//*************************************************************************************************




//=================================================================================================
//
//  MATHEMATICAL CONSTANT LOG2E
//
//=================================================================================================

#ifdef M_LOG2E
#  undef M_LOG2E
#endif

//*************************************************************************************************
/*!\brief Definition of the mathematical constant \f$ \log_2 e \f$.
// \ingroup math
*/
const real M_LOG2E = 1.4426950408889634073599246810018921;
//*************************************************************************************************




//=================================================================================================
//
//  MATHEMATICAL CONSTANT LOG10E
//
//=================================================================================================

#ifdef M_LOG10E
#  undef M_LOG10E
#endif

//*************************************************************************************************
/*!\brief Definition of the mathematical constant \f$ \log_{10} e \f$.
// \ingroup math
*/
const real M_LOG10E = 0.4342944819032518276511289189166051;
//*************************************************************************************************




//=================================================================================================
//
//  MATHEMATICAL CONSTANT LN2
//
//=================================================================================================

#ifdef M_LN2
#  undef M_LN2
#endif

//*************************************************************************************************
/*!\brief Definition of the mathematical constant \f$ \ln 2 \f$.
// \ingroup math
*/
const real M_LN2 = 0.6931471805599453094172321214581766;
//*************************************************************************************************




//=================================================================================================
//
//  MATHEMATICAL CONSTANT LN10
//
//=================================================================================================

#ifdef M_LN10
#  undef M_LN10
#endif

//*************************************************************************************************
/*!\brief Definition of the mathematical constant \f$ \ln 10 \f$.
// \ingroup math
*/
const real M_LN10 = 2.3025850929940456840179914546843642;
//*************************************************************************************************




//=================================================================================================
//
//  MATHEMATICAL CONSTANT PI
//
//=================================================================================================

#ifdef M_PI
#  undef M_PI
#endif

//*************************************************************************************************
/*!\brief Definition of the mathematical constant \f$ \pi \f$.
// \ingroup math
*/
const real M_PI = 3.1415926535897932384626433832795029;
//*************************************************************************************************




//=================================================================================================
//
//  MATHEMATICAL CONSTANT SQRT2
//
//=================================================================================================

#ifdef M_SQRT2
#  undef M_SQRT2
#endif

//*************************************************************************************************
/*!\brief Definition of the mathematical constant \f$ \sqrt{2} \f$.
// \ingroup math
*/
const real M_SQRT2 = 1.4142135623730950488016887242096981;
//*************************************************************************************************




//=================================================================================================
//
//  MATHEMATICAL CONSTANT SQRT3
//
//=================================================================================================

#ifdef M_SQRT3
#  undef M_SQRT3
#endif

//*************************************************************************************************
/*!\brief Definition of the mathematical constant \f$ \sqrt{3} \f$.
// \ingroup math
*/
const real M_SQRT3 = 1.7320508075688772935274463415058724;
//*************************************************************************************************

} // namespace blaze

#endif
